@@ -158,15 +158,40 @@ cb_about (GtkAction *action, gpointer data)
     ProcData *procdata = static_cast<ProcData*>(data);
 
     const gchar * const authors[] = {
-        "Kevin Vandersloot",
+        "Adam Erdman <hekel@archlinux.info>",
+        "Alexander Pyhalov <apyhalov@gmail.com>",
+        "Andreas Nilsson <nisses.mail@home.se>",
+        "Benoît Dejean <bdejean@gmail.com>",
+        "Chris Kühl <chrisk@openismus.com>",
+        "Clement Lefebvre <clement.lefebvre@linuxmint.com>",
+        "Elias Aebi <user142@hotmail.com>",
         "Erik Johnsson",
         "Jorgen Scheibengruber",
-        "Benoît Dejean",
-        "Paolo Borelli",
         "Karl Lattimer",
-        "Perberos",
-        "Stefano Karapetsas",
-        "Steve Zesch",
+        "Kevin Vandersloot",
+        "Laurent Napias <tamplan@free.fr>",
+        "Marcel Dijkstra <marcel.dykstra@gmail.com>",
+        "Martin Wimpress <martin@mate-desktop.org>",
+        "Matias De lellis <mati86dl@gmail.com>",
+        "Mike Gabriel <mike.gabriel@das-netzwerkteam.de>",
+        "Nelson Marques <nmo.marques@gmail.com>",
+        "Obata Akio https://github.com/obache",
+        "Pablo Barciela <scow@riseup.net>",
+        "Paolo Borelli",
+        "Perberos <perberos@gmail.com>",
+        "Piotr Drąg <piotrdrag@gmail.com>",
+        "Robert Buj <robert.buj@gmail.com>",
+        "Sander Sweers <infirit@gmail.com>",
+        "Scott Balneaves <sbalneav@alburg.net>",
+        "Soong Noonien https://github.com/SoongNoonien",
+        "Stefano Karapetsas <stefano@karapetsas.com>",
+        "Steve Zesch <stevezesch2@gmail.com>",
+        "Victor Kareh <vkareh@redhat.com>",
+        "Vlad Orlov <monsta@inbox.ru>",
+        "Wolfgang Ulbrich <mate@raveit.de>",
+        "Wu Xiaotian <yetist@gmail.com>",
+        "Yaakov Selkowitz <yselkowitz@users.sourceforge.net>",
+        "Youri Mouton <youri@NetBSD.org>",
         NULL
     };
 
